@@ -1,5 +1,6 @@
 from requests import get
 from bs4 import BeautifulSoup
+import unicodedata
 
 def get_game_suffix(date, team1, team2):
     r = get(f'https://www.basketball-reference.com/boxscores/index.fcgi?year={date.year}&month={date.month}&day={date.day}')
@@ -14,7 +15,8 @@ def get_game_suffix(date, team1, team2):
     return suffix
 
 def get_player_suffix(name):
-    names = name.split(' ')[1:]
+    normalized_name = unicodedata.normalize('NFD', name).encode('ascii', 'ignore').decode("utf-8")
+    names = normalized_name.split(' ')[1:]
     for last_name in names:
         initial = last_name[0].lower()
         r = get(f'https://www.basketball-reference.com/players/{initial}')
@@ -22,6 +24,6 @@ def get_player_suffix(name):
             soup = BeautifulSoup(r.content, 'html.parser')
             for table in soup.find_all('table', attrs={'id': 'players'}):
                 for anchor in table.find_all('a'):
-                    if anchor.text==name:
+                    if anchor.text in name:
                         suffix = anchor.attrs['href']
                         return suffix
